#!/usr/bin/env bash

set -e

# Set context to current namespace
NAMESPACE=$(cat /var/run/secrets/kubernetes.io/serviceaccount/namespace)
kubectl config set-context test --namespace=${NAMESPACE}
kubectl config use-context test
kubectl config view

# Patch tests
cd e2e-tests/data
# For each resource file
ls *.yaml | while read resource_file;do \
  echo "Patching $resource_file"

  # Replace image names
  sed -i "s#FLINK_IMAGE#${FLINK_IMAGE}#g" $resource_file
  sed -i "s#LOCAL_STACK_IMAGE#${LOCAL_STACK_IMAGE}#g" $resource_file

  # Split resource file into individual yamls
  yq -s '"split_" + $index' $resource_file

  # Rename original resource file
  mv $resource_file ${resource_file}.bak

  # For each split
  ls split_*.yml | while read split_file;do \
    # Remove any hardcoded namespace reference from resource
    yq -i 'del(.metadata.namespace)' $split_file

    # Check if it is IngressClass resource
    # If yes, ignore as we are not allowed to add cluster resource
    if ! grep -q -i "kind: IngressClass" $split_file; then
      # If FlinkDeployment resource
      if grep -q -i "kind: FlinkDeployment" $split_file; then
        # Add fsGroup to flink gid 9999. Needed for PV in EKS.
        yq -i '.spec.podTemplate.spec.securityContext.fsGroup = 9999' $split_file

        # Remove volumes from global podTemplate
        yq -i 'del(.spec.podTemplate.spec.volumes)' $split_file

        # Add flink-volume to job manager and task manager podTemplate
        yq -i '.spec.jobManager.podTemplate.spec.volumes = [{"name": "flink-artifact", "emptyDir": {}}]' $split_file
        yq -i '.spec.taskManager.podTemplate.spec.volumes = [{"name": "flink-artifact", "emptyDir": {}}]' $split_file
      fi
      if grep -q -i "kind: PersistentVolumeClaim" $split_file; then
        # EKS need separate PVCs for job manager and task manager
        # So, concatenate two PVCs
        yq '.metadata.name = "jm-pvc"' $split_file >> $resource_file
        yq '.metadata.name = "tm-pvc"' $split_file >> $resource_file
      else
        # Otherwise, concatenate resource
        cat $split_file >> $resource_file
      fi
    fi
  done
  # Remove individual splits
  rm split_*.yml
done
cd ..
# Comment minikube call
sed -i 's/ip=$(minikube ip)/#ip=$(minikube ip)/' utils.sh
# Replace external access with internal service call as test is run within a pod
sed -i 's#http://$ip/default/${CLUSTER_ID}/overview#http://${CLUSTER_ID}-rest:8081/overview#' utils.sh
# Comment out default context set in utils.sh script
sed -i 's/kubectl config set-context --current --namespace=default/#kubectl config set-context --current --namespace=default/' utils.sh
# Remove --all-namespaces
sed -i 's/--all-namespaces//' utils.sh
cd ..
# End patching


# Run tests
mkdir -p /usr/reports
bats -t --report-formatter junit --output /usr/reports --print-output-on-failure --show-output-of-passing-tests --verbose-run ${TEST_FILE}
mv /usr/reports/report.xml /usr/reports/poke_report.xml

# Sleep to give enough time to copy test report
sleep 90
